==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/ConfigurationsServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSetLegacyNoPK;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.DIFRepositoryFactory;
import pt.digitalis.dif.dem.managers.impl.model.IConfigurationsService;
import pt.digitalis.dif.dem.managers.impl.model.data.Configuration;
import pt.digitalis.dif.dem.managers.impl.model.data.ConfigNode;
import pt.digitalis.dif.dem.managers.impl.model.data.ConfigSet;
import pt.digitalis.dif.dem.managers.impl.model.data.ConfigServerSet;

/**
* NOTE: This file is auto generated and will be overwrite in a future file generation.
*/
public class ConfigurationsServiceImpl implements IConfigurationsService {

    /**
     * Obtains a new DataSet for the Configuration entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<Configuration> getConfigurationDataSet() {
        return new HibernateDataSet<Configuration>(Configuration.class, HibernateUtil.getSessionFactory("DIFRepository"),
                Configuration.getPKFieldListAsString(), Configuration.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ConfigNode entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ConfigNode> getConfigNodeDataSet() {
        return new HibernateDataSet<ConfigNode>(ConfigNode.class, HibernateUtil.getSessionFactory("DIFRepository"),
                ConfigNode.getPKFieldListAsString(), ConfigNode.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ConfigSet entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ConfigSet> getConfigSetDataSet() {
        return new HibernateDataSet<ConfigSet>(ConfigSet.class, HibernateUtil.getSessionFactory("DIFRepository"),
                ConfigSet.getPKFieldListAsString(), ConfigSet.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ConfigServerSet entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ConfigServerSet> getConfigServerSetDataSet() {
        return new HibernateDataSet<ConfigServerSet>(ConfigServerSet.class, HibernateUtil.getSessionFactory("DIFRepository"),
                ConfigServerSet.getPKFieldListAsString(), ConfigServerSet.FieldAttributes);
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == Configuration.class)
            return getConfigurationDataSet();

        if (clazz == ConfigNode.class)
            return getConfigNodeDataSet();

        if (clazz == ConfigSet.class)
            return getConfigSetDataSet();

        if (clazz == ConfigServerSet.class)
            return getConfigServerSetDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(Configuration.class.getSimpleName()))
            return getConfigurationDataSet();

        if (entityName.equalsIgnoreCase(ConfigNode.class.getSimpleName()))
            return getConfigNodeDataSet();

        if (entityName.equalsIgnoreCase(ConfigSet.class.getSimpleName()))
            return getConfigSetDataSet();

        if (entityName.equalsIgnoreCase(ConfigServerSet.class.getSimpleName()))
            return getConfigServerSetDataSet();

        return null;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/ConfigurationsServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSetLegacyNoPK;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.DIFRepositoryFactory;
import pt.digitalis.dif.dem.managers.impl.model.IConfigurationsService;
import pt.digitalis.dif.dem.managers.impl.model.data.Configuration;
import pt.digitalis.dif.dem.managers.impl.model.data.ConfigNode;
import pt.digitalis.dif.dem.managers.impl.model.data.ConfigSet;
import pt.digitalis.dif.dem.managers.impl.model.data.ConfigServerSet;

/**
* NOTE: This file is auto generated and will be overwrite in a future file generation.
*/
public class ConfigurationsServiceImpl implements IConfigurationsService {

    /**
     * Constant with the session factory ID
     */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /**
     * Obtains a new DataSet for the Configuration entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<Configuration> getConfigurationDataSet() {
        return new HibernateDataSet<Configuration>(Configuration.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                Configuration.getPKFieldListAsString(), Configuration.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ConfigNode entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ConfigNode> getConfigNodeDataSet() {
        return new HibernateDataSet<ConfigNode>(ConfigNode.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                ConfigNode.getPKFieldListAsString(), ConfigNode.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ConfigSet entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ConfigSet> getConfigSetDataSet() {
        return new HibernateDataSet<ConfigSet>(ConfigSet.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                ConfigSet.getPKFieldListAsString(), ConfigSet.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ConfigServerSet entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ConfigServerSet> getConfigServerSetDataSet() {
        return new HibernateDataSet<ConfigServerSet>(ConfigServerSet.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                ConfigServerSet.getPKFieldListAsString(), ConfigServerSet.FieldAttributes);
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == Configuration.class)
            return getConfigurationDataSet();

        if (clazz == ConfigNode.class)
            return getConfigNodeDataSet();

        if (clazz == ConfigSet.class)
            return getConfigSetDataSet();

        if (clazz == ConfigServerSet.class)
            return getConfigServerSetDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(Configuration.class.getSimpleName()))
            return getConfigurationDataSet();

        if (entityName.equalsIgnoreCase(ConfigNode.class.getSimpleName()))
            return getConfigNodeDataSet();

        if (entityName.equalsIgnoreCase(ConfigSet.class.getSimpleName()))
            return getConfigSetDataSet();

        if (entityName.equalsIgnoreCase(ConfigServerSet.class.getSimpleName()))
            return getConfigServerSetDataSet();

        return null;
    }
}
